If mastering an additional attribute lead to a lower probabilities of success, the monotonicity is violated.
Arguments
- object
object of class
GDINA- strict
whether a strict monotonicity is checked?
If mastering an additional attribute lead to a lower probabilities of success, the monotonicity is violated.
object of class GDINA
whether a strict monotonicity is checked?