| CM | R Documentation |
This function computes profile-level and attribute-level misclassification
matrices from a fitted GDINA model. This function is only applicable
to models with binary attributes.
CM(object, classification = "MAP", matrixtype = "profile")
object |
An estimated GDINA object returned from |
classification |
A character string specifying the classification rule.
Supported values are |
matrixtype |
A character string specifying which matrix to return.
Supported values are |
The profile-level matrix is computed from posterior latent class probabilities. The attribute-level matrices are computed from marginal attribute mastery probabilities and the chosen classifications.
Depending on matrixtype, the function returns one of the
following:
"profile"A class-by-class matrix of estimated
P(\hat{\alpha} = c' \mid \alpha = c).
"attribute"A list of 2 \times 2 matrices, one for
each attribute, with estimated
P(\hat{\alpha}_k = a' \mid \alpha_k = a).
"both"A list with elements profile_classification
and att_classification.
For both pattern-level and attribute-level matrices, rows correspond to true classes and columns correspond to classified classes.
Wenchao Ma, The University of Minnesota, wma@umn.edu
## Not run:
dat <- realdata_ECPE$dat
Q <- realdata_ECPE$Q
fit <- GDINA(dat = dat, Q = Q, model = "GDINA")
CM(fit)
CM(fit, matrixtype = "both")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.