This function generates the design matrix for an item
Arguments
- Kj
Required except for the MS-DINA model; The number of attributes required for item j
- model
the model associated with the design matrix; It can be "GDINA","DINA","DINO", "ACDM","LLM", "RRUM", "MSDINA", "BUGDINO", and "SISM". The default is "GDINA". Note that models "LLM" and "RRUM" have the same design matrix as the "ACDM".
- Qj
the Q-matrix for item j; This is required for "MSDINA", and "SISM" models; The number of rows is equal to the number of strategies for "MSDINA", and the number of columns is equal to the number of attributes.
- no.bugs
the number of bugs (or misconceptions). Note that bugs must be given in the last no.bugs columns.