Calculate item fit statistics from the power-divergence family
itemfitPD(
GDINA.obj,
lambda = 2/3,
bootstrap = FALSE,
R = 1000,
Stone = FALSE,
init.parm = FALSE,
p.adjust.method = "holm",
person.sim = "post",
cores = 2,
digits = 4,
bound = 1e-10,
seed = 123456
)Object containing a model fitted with the GDINA::GDINA function.
Numeric; parameter for the power-divergence fit statistic.
Logical; whether parametric bootstrap should be used.
Integer; number of replicates in the bootstrap procedure if used.
Logical; whether Stone indices should be computed (only available if bootstrap = TRUE).
Logical; whether the estimated item parameters are used in the estimation of the bootstrap replications.
p-values can be adjusted for multiple comparisons at item level. This is conducted using p.adjust function in stats,
and therefore all adjustment methods supported by p.adjust can be used, including "holm",
"hochberg", "hommel", "bonferroni", "BH" and "BY". See p.adjust
for more details. "holm" is the default.
Character; how to simulate attribute profiles in the bootstrap replications.
Integer; number of cores for parallelization during bootstrap.
Integer; number of decimal digits to report.
Numeric; minimum possible value for probabilities.
random seed.
an object of class itemfitPD consisting of several elements including:
the proportion correct statistics, adjusted and unadjusted p values for each item
the transformed correlations, adjusted and unadjusted p values for each item pair
the log odds ratios, adjusted and unadjusted p values for each item pair
the maximum proportion correct, transformed correlation, and log-odds ratio for each item with associated item-level adjusted p-values
#' @importFrom foreach
Najera, P., Ma, W., Sorrel, M. A. and Abad, F. J. (2025). Assessing Item-Level Fit for the Sequential G-DINA Model.Behaviormetrika.
if (FALSE) { # \dontrun{
dat <- sim10GDINA$simdat
Q <- sim10GDINA$simQ
mod1 <- GDINA(dat = dat, Q = Q, model = "GDINA")
mod1
PDfit <- itemfitPD(mod1)
PDfit
dat <- sim21seqDINA$simdat
Q <- sim21seqDINA$simQ
sDINA <- GDINA(dat,Q,model="DINA",sequential = TRUE)
PDfit <- itemfitPD(sDINA)
PDfit
PDfit <- itemfitPD(sDINA, bootstrap = TRUE, Stone = TRUE, cores = 10)
PDfit
} # }