Function to calculate various person attribute parameters, including "EAP",
"MAP", and "MLE", for EAP, MAP and MLE estimates of
attribute patterns (see Huebner & Wang, 2011), "mp" for marginal mastery probabilities, and "HO"
for higher-order ability estimates if a higher-order model is fitted.
See GDINA for examples.
Usage
personparm(object, what = c("EAP", "MAP", "MLE", "mp", "HO"), digits = 4, ...)Arguments
- object
estimated GDINA object returned from
GDINA- what
what to extract; It can be
"EAP","MAP", and"MLE", for EAP, MAP and MLE estimates of attribute patterns, and"mp"for marginal mastery probabilities, and"HO"for higher-order ability estimates if a higher-order model is fitted.- digits
number of decimal places.
- ...
additional arguments
References
Huebner, A., & Wang, C. (2011). A note on comparing examinee classification methods for cognitive diagnosis models. Educational and Psychological Measurement, 71, 407-419.
Author
Wenchao Ma, The University of Alabama, wenchao.ma@ua.edu
Jimmy de la Torre, The University of Hong Kong